##==============================================================================================================
##Clear workspace
##Set working directory
##Load relevant libraries
##==============================================================================================================
	rm(list=ls())
	setwd("C:\\")

	require(data.table)
	require(ggplot2)

##==============================================================================================================
##Import data
##==============================================================================================================
	#read relevant data
		folder				<- "C:\\marriage_outcomes_complete"
		file_names			<- list.files(folder)
		imported_run_data	<- lapply(file_names, function(x){fread(paste(substr(folder, 1, nchar(folder)),"\\",x, sep =""), skip = 33, header = T, sep = " " , stringsAsFactors=FALSE, na.strings = "NA")})
		dat					<- rbindlist(imported_run_data)

	#reduce to focal cases
		dat 				<- dat[dat$year_marriage >= 1950 & dat$year_marriage < 2005]

##==============================================================================================================
##Recode education for analysis
##==============================================================================================================	
	dat$m_s_reduced[dat$m_s >= 1 & dat$m_s <= 2	]	<- 1
	dat$m_s_reduced[dat$m_s == 3				]	<- 2
	dat$m_s_reduced[dat$m_s == 4 				]	<- 3
	
	dat$f_s_reduced[dat$f_s >= 1 & dat$f_s <= 2	]	<- 1
	dat$f_s_reduced[dat$f_s == 3				]	<- 2
	dat$f_s_reduced[dat$f_s == 4				]	<- 3

##==============================================================================================================
##Create divorce indicator
##==============================================================================================================	
	dat$divorced 										<- 0
	dat$divorced[dat$dissolution_reason == "divorce"] 	<- 1

##==============================================================================================================
##Group marriage years
##==============================================================================================================	
	dat$five_cohort 				<- cut(floor(dat$year_marriage), breaks = seq(1899, 2070, by = 5), dig.lab = 20)	
	dat$five_cohort_short			<- substring(dat$five_cohort, 9, 10)

	dat$five_cohort_short_double[dat$five_cohort_short == "54"] <- "50-54"
	dat$five_cohort_short_double[dat$five_cohort_short == "59"] <- "55-59"
	dat$five_cohort_short_double[dat$five_cohort_short == "64"] <- "60-64"
	dat$five_cohort_short_double[dat$five_cohort_short == "69"] <- "65-69"
	dat$five_cohort_short_double[dat$five_cohort_short == "74"] <- "70-74"
	dat$five_cohort_short_double[dat$five_cohort_short == "79"] <- "75-79"
	dat$five_cohort_short_double[dat$five_cohort_short == "84"] <- "80-84"
	dat$five_cohort_short_double[dat$five_cohort_short == "89"] <- "85-89"
	dat$five_cohort_short_double[dat$five_cohort_short == "94"] <- "90-94"
	dat$five_cohort_short_double[dat$five_cohort_short == "99"] <- "95-99"
	dat$five_cohort_short_double[dat$five_cohort_short == "04"] <- "00-04"
	
	dat$five_cohort_short_double 	<- factor(dat$five_cohort_short_double, levels = c("50-54","55-59","60-64","65-69","70-74","75-79","80-84","85-89","90-94","95-99","00-04"))
	
##==============================================================================================================
##Aggregate information about educational assortative mating and dissolution by marriage type
##==============================================================================================================
	#create variables that indicate the different couple types
		dat$hyper	<- 0
		dat$homo	<- 0
		dat$hypo	<- 0
		
		dat$hyper[dat$m_s_reduced > dat$f_s_reduced]	<- 1
		dat$homo[dat$m_s_reduced == dat$f_s_reduced]	<- 1
		dat$hypo[dat$m_s_reduced < dat$f_s_reduced]		<- 1

	#share divorced run level
		divorced_run_level_hyper	<- aggregate(divorced ~ country + random_id + five_cohort_short_double, data = dat[hyper == 1,], mean)
		divorced_run_level_homo		<- aggregate(divorced ~ country + random_id + five_cohort_short_double, data = dat[homo  == 1,], mean)
		divorced_run_level_hypo		<- aggregate(divorced ~ country + random_id + five_cohort_short_double, data = dat[hypo  == 1,], mean)
		divorced_run_level_total	<- aggregate(divorced ~ country + random_id + five_cohort_short_double, data = dat, mean)

		colnames(divorced_run_level_hyper)[ncol(divorced_run_level_hyper)] 	<- "Hypergamous"
		colnames(divorced_run_level_homo)[ncol(divorced_run_level_homo)] 	<- "Homogamous"
		colnames(divorced_run_level_hypo)[ncol(divorced_run_level_hypo)] 	<- "Hypogamous"
		colnames(divorced_run_level_total)[ncol(divorced_run_level_total)] 	<- "All"

		divorced_run_level <- merge(divorced_run_level_hyper, divorced_run_level_homo, all.x = TRUE, all.y = TRUE)
		divorced_run_level <- merge(divorced_run_level, divorced_run_level_hypo, all.x = TRUE, all.y = TRUE)
		divorced_run_level <- merge(divorced_run_level, divorced_run_level_total, all.x = TRUE, all.y = TRUE)

	#share divorced country level
		divorced_country_level 						<- aggregate(cbind(Hypergamous, Homogamous, Hypogamous, All) ~ country + five_cohort_short_double, data = divorced_run_level, mean, na.rm=TRUE, na.action=NULL)
		divorced_country_level$log_ratio_hypo_hyper	<- log(divorced_country_level$Hypogamous / divorced_country_level$Hypergamous)
	
	#share divorced EU level
		divorced_EU_level							<- aggregate(cbind(Hypergamous, Homogamous, Hypogamous, All) ~ five_cohort_short_double, data = divorced_country_level, mean, na.rm=TRUE, na.action=NULL)	

##==============================================================================================================
##Figure 2
##==============================================================================================================			
	divorced_EU_level_long		<- melt(divorced_EU_level, id=c("five_cohort_short_double"))					
													
	labl <- list(	expression('Hypergamous ('~ italic('s')[m]  ~ '>' ~ italic('s')[f] ~ ')'), 
					expression('Homogamous (' ~ italic('s')[m]  ~ '=' ~ italic('s')[f] ~ ')'),
					expression('Hypogamous (' ~ italic('s')[m]  ~ '<' ~ italic('s')[f] ~ ')'), 
					'All')

		ggplot(data=divorced_EU_level_long[divorced_EU_level_long$variable != "diff_hypo_hyper" & divorced_EU_level_long$variable != "log_ratio_hypo_hyper",],
			aes(x=five_cohort_short_double, y=value, group = variable, shape = variable, linetype=variable)) +
			labs(list(x = "Marriage cohort", y = "Average share of marriages ending in divorce"), size = 20)+
			ylim(0, .25) +

			geom_line(aes(linetype=variable))+
			geom_point(aes(shape=variable)) +
			
			geom_line()+
			geom_point(fill = "black", size = 2) +
				
			theme(axis.text.y 			= element_text(colour="black", size = 10)) + 
			theme(axis.text.x 			= element_text(colour="black", size = 10, angle = 45,hjust = 1)) + 
			theme(axis.title			= element_text(colour="black", size = 12)) +

			theme(axis.ticks 			= element_line(colour = 'black')) +
			theme(panel.grid.minor.x 	= element_blank()) +
			theme(panel.grid.major.x 	= element_blank()) +
			theme(panel.grid.major.y 	= element_blank()) +
			theme(panel.grid.minor.y 	= element_blank()) +
			theme(panel.border 			= element_blank()) +
			theme(panel.background 		= element_blank()) +	
			theme(axis.line = element_line(color = 'black')) +
			
			theme(text 					= element_text(size=12)) +
			theme(legend.text			= element_text(size=12)) +
			theme(legend.position		= "bottom") +
			theme(legend.key 			= element_rect(fill = 'white')) +
			theme(legend.title			= element_text(size=12)) +
			
			guides(shape = guide_legend(nrow = 2,'Marriage type'), linetype = guide_legend(nrow = 2,'Marriage type')) +
			scale_shape_manual(values=c(24,21,25, 4), labels = labl) +
			scale_linetype_manual (values=c(1,2,3,4), labels = labl)

##==============================================================================================================
##Figure 3
##==============================================================================================================		
	divorced_country_level_long	<- melt(divorced_country_level, id=c("five_cohort_short_double", "country"))

		ggplot(data=divorced_country_level_long[divorced_country_level_long$variable == "log_ratio_hypo_hyper",],
			aes(x=five_cohort_short_double, y=value, group = variable)) +
			labs(list(x = "Marriage cohort", y = expression("Relative divorce risk" ~ " (" ~ italic(R)~ ")"))) +
			facet_wrap(~ country, ncol = 4, scales='free') +
			scale_x_discrete(labels=c("50-54","","60-64","","70-74","","80-84","","90-94","","00-04")) +

			ylim(-.5, 1) +
				
			geom_line()+
			geom_point(fill = "black", size = 1) +
			geom_hline(yintercept = 0) + 
			
			theme(axis.text.y 			= element_text(colour = "black", size = 10)) + 
			theme(axis.title			= element_text(colour = "black", size = 12)) +
			theme(axis.ticks 			= element_line(colour = 'black')) +
			theme(panel.grid.minor.x 	= element_blank()) +
			theme(panel.grid.major.x 	= element_blank()) +
			theme(panel.grid.major.y 	= element_blank()) +
			theme(panel.grid.minor.y 	= element_blank()) +
			theme(panel.border 			= element_blank()) +
			theme(panel.background 		= element_blank()) +	
			theme(strip.background 		= element_blank()) +
			theme(strip.text 			= element_text(face='bold', size = 10)) +
			theme(axis.line = element_line(color = 'black')) +
			
			theme(text 					= element_text(size=10)) +
			theme(legend.text			= element_text(size=10)) +
			theme(legend.position		= "bottom") +
			theme(legend.key 			= element_rect(fill = 'white')) +
			theme(legend.title			= element_text(size=10)) +
			
			guides(shape = guide_legend(nrow = 1,byrow=TRUE, 'Marriage type'), linetype = guide_legend("Marriage type"), fill = "none", nrow = 2) +
			scale_shape_manual(values=c(24,21,25, 4))		

##==============================================================================================================
##Figure 4
##==============================================================================================================			
	#determine length of marriage and trim at 30 years
		dat$marriage_duration 										<- dat$year_dissolution - dat$year_marriage
		dat$marriage_duration_aux 									<- dat$marriage_duration
		dat$marriage_duration_aux[dat$marriage_duration_aux > 30] 	<- 30

	#calculate some average and maximal relationship lengths
		average_duration_total	<- aggregate(marriage_duration ~ 1, data = dat[divorced == 1,], mean)
		average_duration_cohort <- aggregate(marriage_duration ~ five_cohort_short_double, data = dat[divorced == 1,], mean)
	
	#share dissolved by duration	
		share_dissolved	<- aggregate(divorced / nrow(dat) ~ marriage_duration_aux, data = dat, sum)
		colnames(share_dissolved)[2] <- "share_diss"

		ggplot(data=share_dissolved, aes(x=marriage_duration_aux, y = share_diss)) + 	
			geom_bar(stat = "summary",color = "black", fill = "white") + 

			xlim(-1,32) +

			labs(list(x = "Years between marriage and divorce", y = "Share of marriages divorced"))+
			
			annotate("text", x = 8, y = .03, label= paste("av. years = ", round((average_duration_total$marriage_duration),2)), size = 4) + 			
			geom_vline(aes(xintercept=average_duration_total$marriage_duration), data=average_duration_total, lty = "longdash", colour = "black") +
		
			theme(axis.text.y 			= element_text(colour = "black", size = 10)) + 
			theme(axis.text.x 			= element_text(colour = "black", size = 10)) +
			theme(axis.title			= element_text(colour = "black", size = 12)) +			
			theme(axis.ticks 			= element_line(colour = 'black')) +
			theme(panel.grid.minor.x 	= element_blank()) +
			theme(panel.grid.major.x 	= element_blank()) +
			theme(panel.grid.major.y 	= element_blank()) +
			theme(panel.grid.minor.y 	= element_blank()) +
			theme(panel.border 			= element_blank()) +
			theme(panel.background 		= element_blank()) +	
			theme(strip.background 		= element_blank()) +
			theme(strip.text 			= element_text(face='bold', size = 10)) +
			theme(axis.line = element_line(color = 'black')) +
			
			theme(text 					= element_text(size = 10)) +
			theme(legend.text			= element_text(size = 10)) +
			theme(legend.position		= "bottom") +
			theme(legend.key 			= element_rect(fill = 'white')) +
			theme(legend.title			= element_text(size = 10)) +
			scale_y_continuous(labels=function(x) format(x, big.mark = ",", scientific = FALSE))

##==============================================================================================================
##Attach F-index data based on IIASA/VID
##==============================================================================================================
	#load the data
		load(file = "C:\\f_index_data.RData")

	#attach IIASA/VID F-index data	
		divorced_country_level_long$ref_year 	<- as.numeric(as.character(substring(divorced_country_level_long$five_cohort_short_double, 1, 2))) + 1905
		divorced_country_level_long$ref_year[divorced_country_level_long$ref_year == 1905] <- 2005
	
		colnames(f_index_data)[2] 			<- "ref_year"
		divorced_country_level_long 		<- merge(divorced_country_level_long , f_index_data, by = intersect(names(divorced_country_level_long), names(f_index_data)))

##==============================================================================================================
##Figure 5
##==============================================================================================================
	ggplot(data=divorced_country_level_long[divorced_country_level_long$variable == "log_ratio_hypo_hyper",],
		aes(x=findex, y=value, group = country)) +
		labs(list(x = expression("Female educational advantage " ~ " (" ~ italic(F)~ ")"), y = expression("Relative divorce risk" ~ " (" ~ italic(R)~ ")")))+
		
		ylim(-.5,1) +
		xlim(0.17,.7) +

		geom_point() +
		geom_hline(yintercept=0) + 		
			
		theme(axis.text.y 			= element_text(colour = "black", size = 10)) + 
		theme(axis.text.x 			= element_text(colour = "black", size = 10)) +
		theme(axis.title			= element_text(colour = "black", size = 12)) +				
		theme(axis.ticks 			= element_line(colour = 'black')) +
		theme(panel.grid.minor.x 	= element_blank()) +
		theme(panel.grid.major.x 	= element_blank()) +
		theme(panel.grid.major.y 	= element_blank()) +
		theme(panel.grid.minor.y 	= element_blank()) +
		theme(panel.border 			= element_blank()) +
		theme(panel.background 		= element_blank()) +	
		theme(strip.background 		= element_blank()) +
		theme(strip.text 			= element_text(face='bold', size = 10)) +
		theme(axis.line = element_line(color = 'black')) +
		
		theme(text 					= element_text(size = 10)) +
		theme(legend.text			= element_text(size = 10)) +
		theme(legend.position		= "bottom") +
		theme(legend.key 			= element_rect(fill = 'white')) +
		theme(legend.title			= element_text(size = 10)) +
	
		guides(linetype = guide_legend("Marriage type"), fill = "none")

##==============================================================================================================
##Figure 6
##==============================================================================================================												
	labl <- list(	expression('Hypergamous ('~ italic('s')[m]  ~ '>' ~ italic('s')[f] ~ ')'), 
					expression('Hypogamous (' ~ italic('s')[m]  ~ '<' ~ italic('s')[f] ~ ')'))

	data_red <- divorced_country_level_long[divorced_country_level_long$variable == "Hypergamous" | divorced_country_level_long$variable == "Hypogamous",]

		ggplot(data=data_red,
			aes(x=findex, y=value, group = variable, linetype = variable, shape = variable)) +
			facet_wrap(~ country, ncol = 4, scales='free') +

			labs(list(x = expression("Female educational advantage " ~ " (" ~ italic(F)~ ")"), y = "Average share of marriages ending in divorce"))+
			
			ylim(.0,.4) +
			xlim(.15,.7) +

			geom_point(fill = "black", size = 2) +		
			geom_smooth(method ='lm', fill=NA, colour = "black", fullrange = TRUE) +
	
			theme(axis.text.y 			= element_text(colour = "black", size = 10)) + 
			theme(axis.text.x 			= element_text(colour = "black", size = 10, angle = 45,hjust = 1)) + 
			theme(axis.title			= element_text(colour = "black", size = 12)) +							
			theme(axis.ticks 			= element_line(colour = 'black')) +
			theme(panel.grid.minor.x 	= element_blank()) +
			theme(panel.grid.major.x 	= element_blank()) +
			theme(panel.grid.major.y 	= element_blank()) +
			theme(panel.grid.minor.y 	= element_blank()) +
			theme(panel.border 			= element_blank()) +
			theme(panel.background 		= element_blank()) +	
			theme(strip.background 		= element_blank()) +
			theme(strip.text 			= element_text(face='bold', size = 10)) +
			theme(axis.line = element_line(color = 'black')) +
			
			theme(text 					= element_text(size = 10)) +
			theme(legend.text			= element_text(size = 12)) +
			theme(legend.position		= "bottom") +
			theme(legend.key 			= element_rect(fill = 'white')) +
			theme(legend.title			= element_text(size = 12)) +
		
			guides(shape = guide_legend(nrow = 1,'Marriage type'), linetype = guide_legend(nrow = 1,'Marriage type')) +
			scale_linetype_manual (values=c(1,2), labels = labl) +
			scale_shape_manual(values=c(19,1), labels = labl)
			