##==============================================================================================================
##Clear workspace
##Set working directory
##Load relevant libraries
##==============================================================================================================
	rm(list=ls())
	setwd("C:\\")

	require(data.table)

	
##==============================================================================================================
##Import data
##==============================================================================================================
	#read relevant data
		folder				<- "C:\\marriage_outcomes_no_s"
		file_names			<- list.files(folder)	
		imported_run_data	<- lapply(file_names, function(x){fread(paste(substr(folder, 1, nchar(folder)),"\\",x, sep =""), skip = 33, header = T, sep = " " , stringsAsFactors=FALSE, na.strings = "NA")})
		dat					<- rbindlist(imported_run_data)
		
	#reduce to focal cases
		dat 				<- dat[dat$year_marriage >= 1950 & dat$year_marriage < 2005]

##==============================================================================================================
##Recode education for analysis
##==============================================================================================================	
	dat$m_s_reduced[dat$m_s >= 1 & dat$m_s <= 2	]	<- 1
	dat$m_s_reduced[dat$m_s == 3				]	<- 2
	dat$m_s_reduced[dat$m_s == 4 				]	<- 3
	
	dat$f_s_reduced[dat$f_s >= 1 & dat$f_s <= 2	]	<- 1
	dat$f_s_reduced[dat$f_s == 3				]	<- 2
	dat$f_s_reduced[dat$f_s == 4				]	<- 3

##==============================================================================================================
##Create divorce indicator
##==============================================================================================================	
	dat$divorced 										<- 0
	dat$divorced[dat$dissolution_reason == "divorce"] 	<- 1

##==============================================================================================================
##Group marriage years
##==============================================================================================================	
	dat$five_cohort 				<- cut(floor(dat$year_marriage), breaks = seq(1899, 2070, by = 5), dig.lab = 20)	
	dat$five_cohort_short			<- substring(dat$five_cohort, 9, 10)

	dat$five_cohort_short_double[dat$five_cohort_short == "54"] <- "50-54"
	dat$five_cohort_short_double[dat$five_cohort_short == "59"] <- "55-59"
	dat$five_cohort_short_double[dat$five_cohort_short == "64"] <- "60-64"
	dat$five_cohort_short_double[dat$five_cohort_short == "69"] <- "65-69"
	dat$five_cohort_short_double[dat$five_cohort_short == "74"] <- "70-74"
	dat$five_cohort_short_double[dat$five_cohort_short == "79"] <- "75-79"
	dat$five_cohort_short_double[dat$five_cohort_short == "84"] <- "80-84"
	dat$five_cohort_short_double[dat$five_cohort_short == "89"] <- "85-89"
	dat$five_cohort_short_double[dat$five_cohort_short == "94"] <- "90-94"
	dat$five_cohort_short_double[dat$five_cohort_short == "99"] <- "95-99"
	dat$five_cohort_short_double[dat$five_cohort_short == "04"] <- "00-04"
	
	dat$five_cohort_short_double 	<- factor(dat$five_cohort_short_double, levels = c("50-54","55-59","60-64","65-69","70-74","75-79","80-84","85-89","90-94","95-99","00-04"))
	
##==============================================================================================================
##Aggregate information about educational assortative mating and dissolution by marriage type
##==============================================================================================================
	#create variables that indicate the different couple types
		dat$hyper	<- 0
		dat$homo	<- 0
		dat$hypo	<- 0
		
		dat$hyper[dat$m_s_reduced > dat$f_s_reduced]	<- 1
		dat$homo[dat$m_s_reduced == dat$f_s_reduced]	<- 1
		dat$hypo[dat$m_s_reduced < dat$f_s_reduced]		<- 1

	#share divorced run level
		divorced_run_level_hyper	<- aggregate(divorced ~ country + random_id + five_cohort_short_double, data = dat[hyper == 1,], mean)
		divorced_run_level_homo		<- aggregate(divorced ~ country + random_id + five_cohort_short_double, data = dat[homo  == 1,], mean)
		divorced_run_level_hypo		<- aggregate(divorced ~ country + random_id + five_cohort_short_double, data = dat[hypo  == 1,], mean)
		divorced_run_level_total	<- aggregate(divorced ~ country + random_id + five_cohort_short_double, data = dat, mean)

		colnames(divorced_run_level_hyper)[ncol(divorced_run_level_hyper)] 	<- "Hypergamous"
		colnames(divorced_run_level_homo)[ncol(divorced_run_level_homo)] 	<- "Homogamous"
		colnames(divorced_run_level_hypo)[ncol(divorced_run_level_hypo)] 	<- "Hypogamous"
		colnames(divorced_run_level_total)[ncol(divorced_run_level_total)] 	<- "All"
	
		divorced_run_level <- merge(divorced_run_level_hyper, divorced_run_level_homo, all.x = TRUE, all.y = TRUE)
		divorced_run_level <- merge(divorced_run_level, divorced_run_level_hypo, all.x = TRUE, all.y = TRUE)
		divorced_run_level <- merge(divorced_run_level, divorced_run_level_total, all.x = TRUE, all.y = TRUE)

	#share divorced country level
		divorced_country_level						<- aggregate(cbind(Hypergamous, Homogamous, Hypogamous, All) ~ country + five_cohort_short_double, data = divorced_run_level, mean, na.rm=TRUE, na.action=NULL)

	#share divorced EU level
		divorced_EU_level							<- aggregate(cbind(Hypergamous, Homogamous, Hypogamous, All) ~ five_cohort_short_double, data = divorced_country_level, mean, na.rm=TRUE, na.action=NULL)
		divorced_EU_level$log_ratio_hyper_hypo		<- log(divorced_EU_level$Hypogamous / divorced_EU_level$Hypergamous)
		
##==============================================================================================================
##Prepare long format and save results
##==============================================================================================================			
	divorced_EU_level_long_no_s				<- melt(divorced_EU_level, id=c("five_cohort_short_double"))
	divorced_EU_level_long_no_s$type		<- "No education preference"

	save(divorced_EU_level_long_no_s, file = "C:\\divorced_EU_level_long_no_s.RData")